abacusai.python_plot_function — AbacusAI documentation

# abacusai.python_plot_function

## Classes

`PythonPlotFunction` | Create a Plot for a Dashboard

## Module Contents

class abacusai.python_plot_function.PythonPlotFunction(client, notebookId=None, name=None, createdAt=None, functionVariableMappings=None, functionName=None, pythonFunctionId=None, functionType=None, plotName=None, graphReferenceId=None, codeSource={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Create a Plot for a Dashboard

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - notebookId (str) – Unique string identifier of the notebook used to spin up the notebook upon creation.

    - name (str) – The name used to identify the algorithm. Only uppercase letters, numbers, and underscores are allowed.

    - createdAt (str) – Date and time when the Python function was created, in ISO-8601 format.

    - functionVariableMappings (dict) – The mappings for function parameters’ names.

    - functionName (str) – The name of the Python function to be used.

    - pythonFunctionId (str) – Unique string identifier of the Python function.

    - functionType (str) – The type of the Python function.

    - plotName (str) – Name of the plot.

    - graphReferenceId (str) – Reference ID of the dashboard to the plot.

    - codeSource (CodeSource) – Info about the source code of the Python function.

  notebook_id
  name
  created_at
  function_variable_mappings
  function_name
  python_function_id
  function_type
  plot_name
  graph_reference_id
  code_source
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict